#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc7
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1RunKind(str, Enum):
    """
    V1RunKind
    """

    """
    allowed enum values
    """
    JOB = 'job'
    SERVICE = 'service'
    DAG = 'dag'
    SPARK = 'spark'
    DASK = 'dask'
    FLINK = 'flink'
    RAY = 'ray'
    MPIJOB = 'mpijob'
    TFJOB = 'tfjob'
    PYTORCHJOB = 'pytorchjob'
    PADDLEJOB = 'paddlejob'
    MXJOB = 'mxjob'
    XGBJOB = 'xgbjob'
    MATRIX = 'matrix'
    SCHEDULE = 'schedule'
    TUNER = 'tuner'
    WATCHDOG = 'watchdog'
    NOTIFIER = 'notifier'
    CLEANER = 'cleaner'
    BUILDER = 'builder'

